camelot.camelot.view.controls.appscheme.Scheme

Package camelot :: Package camelot :: Package view :: Package controls :: Module appscheme :: Class Scheme |
[hide private]
[frames] | no frames]

# Class Scheme

source code

Instance Methods | [hide private]
__init__(self, styledict=`{``'``BorderColor``'``:` `'``(101, 147, 207)``'``,` `'``ButtonMouseOverBegin``'``:` `'``(2``...`) | source code
bordercolor(self) | source code
textcolor(self) | source code
selectedcolor(self) | source code
captiontextcolor(self) | source code
twocolorgradient(self, rgb1, rgb2) | source code
fourcolorgradient(self, rgb1, rgb2, rgb3, rgb4) | source code
normalbackground(self) | source code
hoveredbackground(self) | source code
selectedbackground(self, inverted=False) | source code
captionbackground(self) | source code